/* list.h - structures and prototypes used by list.c and parser.c
           Copyright (C) 2006, 2007 Simeon Simeonov

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */

#ifndef LIST_H
#define LIST_H

#include <stdlib.h>
#include <string.h>
#include <regex.h>

#include "config.h"

typedef struct DHFRule_ {

  regex_t regexp; /* the compiled regexp to match against */
  const char *rule; /* the regexp string. used only by the test module */
  unsigned int action:1; /* 1bit for the action 0 - block, 1 - pass*/
  struct DHFRule_ *next;

} DHFRule;


typedef struct linkedList_ {

  unsigned int size;

  DHFRule *head; /* The first element in the list (the root) */
  DHFRule *tail; /* the last element in the list */

} LinkedList;


void list_init(LinkedList *list);
int list_insert(LinkedList *list, regex_t regexp, unsigned int action);
int list_insert_test(LinkedList *list, const char *rule, regex_t regexp, unsigned int action); /* used only by the test module */

#define list_size(list) ((list)->size)
#define list_root(list) ((list)->head)

#endif
